Nice to have you on board!
--------------------------

If you found an issue or have some new suggestions please make the following:

* Clone the project

    git clone https://github.com/ellisonleao/valid-links.git

* Create a virtualenv (use virtualenvwrapper!) and install requirements

    cd valid-links
    mkvirtualenv valid-links
    pip install requirements.txt
    pip install requirements_dev.txt

* Create a new branch before making the new changes!

    git checkout -b your-feature

* Create a Pull Request and wait for our call.
